A common utils and tornado-based easy setup framework

#### Features
- Python2 and Python3 compatibillity
- Unified time function
- Easy frequently used file operation
- Http utils
- String utils
- Validation utils
- Unified json web api
